@@ -22,9 +22,10 @@ last update:    2020-10-23
 from collections.abc import MutableMapping
 from itertools import count
 
-__all__ = ['PriorityQueue', 'PriorityDict', 'SimplePriorityQueue', 'SimplePriorityDict']
+__all__ = ['PriorityQueue', 'PriorityDict', 'SimplePriorityQueue', 'SimplePriorityDict', 'DEFAULT_MARKER']
 
-_DEFAULT_MARKER = object()
+# DEFAULT_MARKER = object()
+DEFAULT_MARKER = '--+--<<==##** from adk **##==>>--+--'
 
 
 class MinMaxMarker:
@@ -87,7 +88,7 @@ class PriorityQueue:
     def __init__(self, *args, maxsize=0, value_is_prior=False, prior_key=None,
                  format_in=False, format_ou=False,
                  none_is_less=False, complex_prior=False,
-                 empty_return=_DEFAULT_MARKER,
+                 empty_return=DEFAULT_MARKER,
                  **kwargs):
         self._count = count()
         self.heap = []
@@ -144,12 +145,12 @@ class PriorityQueue:
     def to_list_wrap(self):
         return [self.pop_wrap() for _ in range(len(self))]
 
-    def set_empty_return(self, empty_return=_DEFAULT_MARKER):
+    def set_empty_return(self, empty_return=DEFAULT_MARKER):
         self._empty_return = empty_return
 
     def _default_or_error(self, default, errors):
-        if default is _DEFAULT_MARKER:
-            if self._empty_return is _DEFAULT_MARKER:
+        if default == DEFAULT_MARKER:
+            if self._empty_return == DEFAULT_MARKER:
                 raise errors
             else:
                 return self._empty_return
@@ -157,19 +158,19 @@ class PriorityQueue:
             return default
 
     # args: i.e. [key,] value
-    def _wrap(self, *args, prior=_DEFAULT_MARKER):
+    def _wrap(self, *args, prior=DEFAULT_MARKER):
         if self.no_ind_prior:
-            prior = prior if prior is not _DEFAULT_MARKER else args[-1] if self.v_is_p else args[-1][self.p_key]
+            prior = prior if prior != DEFAULT_MARKER else args[-1] if self.v_is_p else args[-1][self.p_key]
             prior_wrap = self._prior_wrap(prior)
             # return [*args, prior_wrap, len(self)]
         else:
-            prior = None if prior is _DEFAULT_MARKER else prior
+            prior = None if prior == DEFAULT_MARKER else prior
             prior_wrap = self._prior_wrap(prior)
             # return [*args, prior, prior_wrap, len(self)]
         return [*args, prior, prior_wrap, len(self)]
 
-    def _unwrap(self, wrapper, fmt=_DEFAULT_MARKER, skip=0):
-        fmt = self.format_ou() if fmt is _DEFAULT_MARKER else fmt
+    def _unwrap(self, wrapper, fmt=DEFAULT_MARKER, skip=0):
+        fmt = self.format_ou() if fmt == DEFAULT_MARKER else fmt
         idx = self.var_idx
 
         if fmt:
@@ -266,40 +267,40 @@ class PriorityQueue:
         wrapper = self.popitem_wrap()
         return self._unwrap(wrapper)
 
-    def peek_wrap(self, default=_DEFAULT_MARKER):
+    def peek_wrap(self, default=DEFAULT_MARKER):
         try:
             return self.heap[0]
         except IndexError as errors:
             return self._default_or_error(default, errors)
 
-    def peek(self, default=_DEFAULT_MARKER):
+    def peek(self, default=DEFAULT_MARKER):
         try:
             return self._unwrap(self.heap[0])
         except IndexError as errors:
             return self._default_or_error(default, errors)
 
-    def push(self, *args, prior=_DEFAULT_MARKER, fmt=_DEFAULT_MARKER):
+    def push(self, *args, prior=DEFAULT_MARKER, fmt=DEFAULT_MARKER):
         args_ln = len(args)
         if not 0 < args_ln < 3:
             raise TypeError('push expected 1~2 arguments, got %d' % args_ln)
         if self.no_ind_prior and args_ln > 1:
             raise TypeError('push expected 1 argument if prior_is_value or prior_key is not None, got %d' % args_ln)
 
-        fmt_in = self.format_in() if fmt is _DEFAULT_MARKER else fmt
+        fmt_in = self.format_in() if fmt == DEFAULT_MARKER else fmt
 
         if args_ln == 1:
             if fmt_in and not self.no_ind_prior:  # confirm args[0] is iterable
                 args = args[0]
                 if len(args) > 1:
-                    prior = prior if prior is not _DEFAULT_MARKER else args[-1]
+                    prior = prior if prior != DEFAULT_MARKER else args[-1]
                 else:
                     args = (args[0], self._none_wrap)
-                    prior = prior if prior is not _DEFAULT_MARKER else None
+                    prior = prior if prior != DEFAULT_MARKER else None
             else:
-                prior = prior if prior is not _DEFAULT_MARKER else (
+                prior = prior if prior != DEFAULT_MARKER else (
                     args[0] if self.v_is_p else args[0][self.p_key]) if self.no_ind_prior else None
         else:
-            prior = prior if prior is not _DEFAULT_MARKER else args[-1]
+            prior = prior if prior != DEFAULT_MARKER else args[-1]
 
         if self.maxsize and len(self) >= self.maxsize:
             self.pop()
@@ -390,34 +391,34 @@ class PriorityDict(PriorityQueue, MutableMapping):
         for v in values:
             self.push(*v)
 
-    def get_wrap(self, key, default=_DEFAULT_MARKER):
+    def get_wrap(self, key, default=DEFAULT_MARKER):
         try:
             return self.dic[key]
         except (KeyError, IndexError) as errors:
             return self._default_or_error(default, errors)
 
-    def get(self, key, default=_DEFAULT_MARKER):
+    def get(self, key, default=DEFAULT_MARKER):
         try:
             return self[key]
         except (KeyError, IndexError) as errors:
             return self._default_or_error(default, errors)
 
-    def peek_wrap(self, key=_DEFAULT_MARKER, default=_DEFAULT_MARKER):
+    def peek_wrap(self, key=DEFAULT_MARKER, default=DEFAULT_MARKER):
         try:
-            return self.heap[0] if key is _DEFAULT_MARKER else self.dic[key]
+            return self.heap[0] if key == DEFAULT_MARKER else self.dic[key]
         except (KeyError, IndexError) as errors:
             return self._default_or_error(default, errors)
 
-    def peek(self, key=_DEFAULT_MARKER, default=_DEFAULT_MARKER):
+    def peek(self, key=DEFAULT_MARKER, default=DEFAULT_MARKER):
         try:
-            return self._unwrap(self.heap[0]) if key is _DEFAULT_MARKER else \
+            return self._unwrap(self.heap[0]) if key == DEFAULT_MARKER else \
                 self._unwrap(self.dic[key])
         except (KeyError, IndexError) as errors:
             return self._default_or_error(default, errors)
 
-    def pop_wrap(self, key=_DEFAULT_MARKER, default=_DEFAULT_MARKER):
+    def pop_wrap(self, key=DEFAULT_MARKER, default=DEFAULT_MARKER):
         try:
-            if key is _DEFAULT_MARKER:
+            if key == DEFAULT_MARKER:
                 return self.popitem_wrap()
             else:
                 value = self.get_wrap(key)
@@ -426,9 +427,9 @@ class PriorityDict(PriorityQueue, MutableMapping):
         except (KeyError, IndexError) as errors:
             return self._default_or_error(default, errors)
 
-    def pop(self, key=_DEFAULT_MARKER, default=_DEFAULT_MARKER):
+    def pop(self, key=DEFAULT_MARKER, default=DEFAULT_MARKER):
         try:
-            if key is _DEFAULT_MARKER:
+            if key == DEFAULT_MARKER:
                 return self.popitem()
             else:
                 value = self[key]
@@ -437,14 +438,14 @@ class PriorityDict(PriorityQueue, MutableMapping):
         except (KeyError, IndexError) as errors:
             return self._default_or_error(default, errors)
 
-    def push(self, *args, prior=_DEFAULT_MARKER, fmt=_DEFAULT_MARKER):
+    def push(self, *args, prior=DEFAULT_MARKER, fmt=DEFAULT_MARKER):
         args_ln = len(args)
         if not 0 < args_ln < 4:
             raise TypeError('push expected 1~3 arguments, got %d' % args_ln)
         if self.no_ind_prior and args_ln > 2:
             raise TypeError('push expected 2 arguments if prior_is_value or prior_key is not None, got %d' % args_ln)
 
-        fmt_in = self.format_in() if fmt is _DEFAULT_MARKER else fmt
+        fmt_in = self.format_in() if fmt == DEFAULT_MARKER else fmt
 
         if args_ln == 1 and fmt_in:
             args = args[0]
@@ -452,15 +453,15 @@ class PriorityDict(PriorityQueue, MutableMapping):
         key = args[0]
 
         if len(args) == 1:
-            if prior is _DEFAULT_MARKER:
+            if prior == DEFAULT_MARKER:
                 if key in self.dic:
                     return
                 else:
                     prior = None
-            value = _DEFAULT_MARKER
+            value = DEFAULT_MARKER
         else:
             value = args  # check format_ou move to __setitem__
-            prior = prior if prior is not _DEFAULT_MARKER else args[-1] if len(args) == 3 \
+            prior = prior if prior != DEFAULT_MARKER else args[-1] if len(args) == 3 \
                 else (args[-1] if self.v_is_p else args[-1][self.p_key]) if self.no_ind_prior else self._none_wrap
 
         if self.maxsize and len(self) >= self.maxsize and key not in self.dic:
@@ -478,13 +479,13 @@ class PriorityDict(PriorityQueue, MutableMapping):
     def __getitem__(self, key):
         return self._unwrap(self.dic[key], skip=1)
 
-    def __setitem__(self, key, value=_DEFAULT_MARKER, prior=_DEFAULT_MARKER, fmt=_DEFAULT_MARKER):
+    def __setitem__(self, key, value=DEFAULT_MARKER, prior=DEFAULT_MARKER, fmt=DEFAULT_MARKER):
         _not_new = key in self.dic
 
-        if prior is not _DEFAULT_MARKER:  # from push
+        if prior != DEFAULT_MARKER:  # from push
             _dft_pri = prior is self._none_wrap
             if not _not_new:
-                if value is _DEFAULT_MARKER:
+                if value == DEFAULT_MARKER:
                     if self.p_key:
                         raise ValueError('expected not only key')
                     value = (key, None)
@@ -495,7 +496,7 @@ class PriorityDict(PriorityQueue, MutableMapping):
         elif self.no_ind_prior:
             _dft_pri = False
             value = (key, value)
-        elif self.format_in() if fmt is _DEFAULT_MARKER else fmt:  # que[key] = (value, [prior])
+        elif self.format_in() if fmt == DEFAULT_MARKER else fmt:  # que[key] = (value, [prior])
             _dft_pri = len(value) == 1  # if fmt, assert value is tuple
             if _dft_pri:
                 value = (key, value[0], self._none_wrap)
@@ -510,7 +511,7 @@ class PriorityDict(PriorityQueue, MutableMapping):
             else:
                 value = (key, value)
 
-        if value is _DEFAULT_MARKER:
+        if value == DEFAULT_MARKER:
             v_saved = self.dic[key][1]
             value = v_saved if len(v_saved) < 3 else (*v_saved[:2], prior)
 
